@@ -16,7 +16,7 @@ def dataform_transform(project_id=os.environ.get("DATAFORM_PROJECT_ID"),
 
 @prefect.task
 def data_monitoring(config):
-    return utils.monitoring.run(rules_list=config["rules"])
+    return utils.monitoring.run(rules_list=json.loads(config)["rules"])
 
 def prefect_parameter_read_json(path,param_name):
         return prefect.Parameter(param_name,
